==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/OrderFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OrderFluentImpl<A extends OrderFluent<A>> extends BaseFluent<A> implements OrderFluent<A>{
  public OrderFluentImpl() {
  }
  public OrderFluentImpl(Order instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private OrderSpecBuilder spec;
  private OrderStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public OrderFluent.MetadataNested<A> withNewMetadata() {
    return new OrderFluentImpl.MetadataNestedImpl();
  }
  public OrderFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new OrderFluentImpl.MetadataNestedImpl(item);
  }
  public OrderFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public OrderFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public OrderFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public OrderSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public OrderSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(OrderSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new OrderSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public OrderFluent.SpecNested<A> withNewSpec() {
    return new OrderFluentImpl.SpecNestedImpl();
  }
  public OrderFluent.SpecNested<A> withNewSpecLike(OrderSpec item) {
    return new OrderFluentImpl.SpecNestedImpl(item);
  }
  public OrderFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public OrderFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new OrderSpecBuilder().build());
  }
  public OrderFluent.SpecNested<A> editOrNewSpecLike(OrderSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public OrderStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public OrderStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(OrderStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new OrderStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public OrderFluent.StatusNested<A> withNewStatus() {
    return new OrderFluentImpl.StatusNestedImpl();
  }
  public OrderFluent.StatusNested<A> withNewStatusLike(OrderStatus item) {
    return new OrderFluentImpl.StatusNestedImpl(item);
  }
  public OrderFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public OrderFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new OrderStatusBuilder().build());
  }
  public OrderFluent.StatusNested<A> editOrNewStatusLike(OrderStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OrderFluentImpl that = (OrderFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OrderFluent.MetadataNested<N>> implements OrderFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) OrderFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends OrderSpecFluentImpl<OrderFluent.SpecNested<N>> implements OrderFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(OrderSpec item) {
      this.builder = new OrderSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new OrderSpecBuilder(this);
    }
    OrderSpecBuilder builder;
    public N and() {
      return (N) OrderFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends OrderStatusFluentImpl<OrderFluent.StatusNested<N>> implements OrderFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(OrderStatus item) {
      this.builder = new OrderStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new OrderStatusBuilder(this);
    }
    OrderStatusBuilder builder;
    public N and() {
      return (N) OrderFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/OrderFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OrderFluentImpl<A extends OrderFluent<A>> extends BaseFluent<A> implements OrderFluent<A>{
  public OrderFluentImpl() {
  }
  public OrderFluentImpl(Order instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private OrderSpecBuilder spec;
  private OrderStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public OrderFluentImpl.MetadataNested<A> withNewMetadata() {
    return new OrderFluentImpl.MetadataNestedImpl();
  }
  public OrderFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new OrderFluentImpl.MetadataNestedImpl(item);
  }
  public OrderFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public OrderFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public OrderFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public OrderSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public OrderSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(OrderSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new OrderSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public OrderFluentImpl.SpecNested<A> withNewSpec() {
    return new OrderFluentImpl.SpecNestedImpl();
  }
  public OrderFluentImpl.SpecNested<A> withNewSpecLike(OrderSpec item) {
    return new OrderFluentImpl.SpecNestedImpl(item);
  }
  public OrderFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public OrderFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new OrderSpecBuilder().build());
  }
  public OrderFluentImpl.SpecNested<A> editOrNewSpecLike(OrderSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public OrderStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public OrderStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(OrderStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new OrderStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public OrderFluentImpl.StatusNested<A> withNewStatus() {
    return new OrderFluentImpl.StatusNestedImpl();
  }
  public OrderFluentImpl.StatusNested<A> withNewStatusLike(OrderStatus item) {
    return new OrderFluentImpl.StatusNestedImpl(item);
  }
  public OrderFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public OrderFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new OrderStatusBuilder().build());
  }
  public OrderFluentImpl.StatusNested<A> editOrNewStatusLike(OrderStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OrderFluentImpl that = (OrderFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OrderFluentImpl.MetadataNested<N>> implements OrderFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) OrderFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends OrderSpecFluentImpl<OrderFluentImpl.SpecNested<N>> implements OrderFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(OrderSpec item) {
      this.builder = new OrderSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new OrderSpecBuilder(this);
    }
    OrderSpecBuilder builder;
    public N and() {
      return (N) OrderFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends OrderStatusFluentImpl<OrderFluentImpl.StatusNested<N>> implements OrderFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(OrderStatus item) {
      this.builder = new OrderStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new OrderStatusBuilder(this);
    }
    OrderStatusBuilder builder;
    public N and() {
      return (N) OrderFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
